@@ -58,6 +58,11 @@ void			 _gtk_source_buffer_set_as_invalid_character	(GtkSourceBuffer        *buf
 G_GNUC_INTERNAL
 gboolean		 _gtk_source_buffer_has_invalid_chars		(GtkSourceBuffer        *buffer);
 
+G_GNUC_INTERNAL
+GtkSourceBracketMatchType
+			 _gtk_source_buffer_find_bracket_match		(GtkSourceBuffer         *buffer,
+									 GtkTextIter             *orig);
+
 G_END_DECLS
 
 #endif /* __GTK_SOURCE_BUFFER_PRIVATE_H__ */
