@@ -101,6 +101,9 @@ struct _GtkSourceFileLoaderPrivate
 	gpointer progress_cb_data;
 	GDestroyNotify progress_cb_notify;
 
+	/* Warning: type instances' private data are limited to a total of 64 KiB.
+	 * See the GType documentation.
+	 */
 	gchar chunk_buffer[READ_CHUNK_SIZE];
 	gssize chunk_bytes_read;
 
@@ -391,7 +394,7 @@ gtk_source_file_loader_class_init (GtkSourceFileLoaderClass *klass)
 	 */
 	g_object_class_install_property (object_class, PROP_LOCATION,
 					 g_param_spec_object ("location",
-							      _("Location"),
+							      "Location",
 							      "",
 							      G_TYPE_FILE,
 							      G_PARAM_READWRITE |
@@ -408,7 +411,7 @@ gtk_source_file_loader_class_init (GtkSourceFileLoaderClass *klass)
 	 */
 	g_object_class_install_property (object_class, PROP_INPUT_STREAM,
 					 g_param_spec_object ("input-stream",
-							      _("Input stream"),
+							      "Input stream",
 							      "",
 							      G_TYPE_INPUT_STREAM,
 							      G_PARAM_READWRITE |
