@@ -137,8 +137,8 @@ gtk_source_mark_class_init (GtkSourceMarkClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_CATEGORY,
 					 g_param_spec_string ("category",
-							      _("category"),
-							      _("The mark category"),
+							      "Category",
+							      "The mark category",
 							      NULL,
 							      G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
@@ -208,7 +208,7 @@ gtk_source_mark_get_category (GtkSourceMark *mark)
  *
  * If @category is %NULL, looks for marks of any category.
  *
- * Returns: (transfer none): the next #GtkSourceMark, or %NULL.
+ * Returns: (nullable) (transfer none): the next #GtkSourceMark, or %NULL.
  *
  * Since: 2.2
  */
@@ -242,7 +242,7 @@ gtk_source_mark_next (GtkSourceMark *mark,
  *
  * If @category is %NULL, looks for marks of any category
  *
- * Returns: (transfer none): the previous #GtkSourceMark, or %NULL.
+ * Returns: (nullable) (transfer none): the previous #GtkSourceMark, or %NULL.
  *
  * Since: 2.2
  */
