@@ -56,6 +56,7 @@ struct _TestWidgetPrivate
 	GtkSpinButton *indent_width_spinbutton;
 	GtkLabel *cursor_position_info;
 	GtkSourceStyleSchemeChooserButton *chooser_button;
+	GtkComboBoxText *background_pattern;
 };
 
 GType test_widget_get_type (void);
@@ -916,6 +917,28 @@ add_source_mark_attributes (GtkSourceView *view)
 	g_object_unref (attrs);
 }
 
+static void
+on_background_pattern_changed (GtkComboBox *combobox,
+                               TestWidget  *self)
+{
+	gchar *text;
+
+	text = gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT (combobox));
+
+	if (g_strcmp0 (text, "Grid") == 0)
+	{
+		gtk_source_view_set_background_pattern (self->priv->view,
+		                                        GTK_SOURCE_BACKGROUND_PATTERN_TYPE_GRID);
+	}
+	else
+	{
+		gtk_source_view_set_background_pattern (self->priv->view,
+		                                        GTK_SOURCE_BACKGROUND_PATTERN_TYPE_NONE);
+	}
+
+	g_free (text);
+}
+
 static void
 test_widget_dispose (GObject *object)
 {
@@ -961,6 +984,7 @@ test_widget_class_init (TestWidgetClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, indent_width_spinbutton);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, cursor_position_info);
 	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, chooser_button);
+	gtk_widget_class_bind_template_child_private (widget_class, TestWidget, background_pattern);
 }
 
 static void
@@ -1013,6 +1037,11 @@ test_widget_init (TestWidget *self)
 	                        "style-scheme",
 	                        G_BINDING_SYNC_CREATE);
 
+	g_signal_connect (self->priv->background_pattern,
+	                  "changed",
+	                  G_CALLBACK (on_background_pattern_changed),
+	                  self);
+
 	open_file (self, TOP_SRCDIR "/gtksourceview/gtksourcebuffer.c");
 }
 
